print.lpbwcde: Print method for local polynomial conditional density...

View source: R/lpbwcde_methods.R

print.lpbwcdeR Documentation

Print method for local polynomial conditional density bandwidth selection

Description

The print method for local polynomial conditional density bandwidth selection objects.

Usage

## S3 method for class 'lpbwcde'
print(x, ...)

Arguments

x

Class "lpbwcde" object, obtained by calling lpbwcde.

...

Other arguments.

Value

Display output

A list of specified options provided to the function.

Author(s)

Matias D. Cattaneo (maintainer). matias.d.cattaneo@gmail.com.

Rajita Chandak. rajita.chandak@gmail.com.

Michael Jansson. michael.jansson.berkeley@gmail.com.

Xinwei Ma. xinweima.pku@gmail.com.

See Also

lpbwcde for data-driven bandwidth selection.

Supported methods: coef.lpbwcde, print.lpbwcde, summary.lpbwcde.

Examples

n <- 100
x_data <- as.matrix(rnorm(n, mean = 0, sd = 1))
y_data <- as.matrix(rnorm(n, mean = 0, sd = 1))
y_grid <- stats::quantile(y_data, seq(from = 0.1, to = 0.9, by = 0.1))
# bandwidth selection
y_grid <- stats::quantile(y_data, seq(from = 0.1, to = 0.9, by = 0.1))
model2 <- lpcde::lpbwcde(y_data = y_data, x_data = x_data, x = 0,
                         y_grid = y_grid, bw_type = "mse-rot")
print(model2)


lpcde documentation built on May 21, 2026, 5:09 p.m.