summary.lpbwcde: Summary method for local polynomial conditional density...

View source: R/lpbwcde_methods.R

summary.lpbwcdeR Documentation

Summary method for local polynomial conditional density bandwidth selection

Description

The summary method for local polynomial conditional density bandwidth selection objects.

Usage

## S3 method for class 'lpbwcde'
summary(object, ...)

Arguments

object

Class "lpbwcde" object, obtained by calling lpbwcde.

...

Additional options, including (i) y_grid specifies a subset of y_grid points to display the bandwidth; (ii) gridIndex specifies the indices of y_grid points to display the bandwidth.

Value

Display output

A list of specified options and a matrix of grid points, bandwidth, and effective sample size.

Author(s)

Matias D. Cattaneo (maintainer). matias.d.cattaneo@gmail.com.

Rajita Chandak. rajita.chandak@gmail.com.

Michael Jansson. michael.jansson.berkeley@gmail.com.

Xinwei Ma. xinweima.pku@gmail.com.

See Also

lpbwcde for data-driven bandwidth selection.

Supported methods: coef.lpbwcde, print.lpbwcde, summary.lpbwcde.

Examples

n <- 100
x_data <- as.matrix(rnorm(n, mean = 0, sd = 1))
y_data <- as.matrix(rnorm(n, mean = 0, sd = 1))
y_grid <- stats::quantile(y_data, seq(from = 0.1, to = 0.9, by = 0.1))
# bandwidth selection
y_grid <- stats::quantile(y_data, seq(from = 0.1, to = 0.9, by = 0.1))
model2 <- lpcde::lpbwcde(y_data = y_data, x_data = x_data, x = 0,
                         y_grid = y_grid, bw_type = "mse-rot")
summary(model2)


lpcde documentation built on May 21, 2026, 5:09 p.m.